@@ -19,13 +19,6 @@ class TextCompletionResponse(Record):
     out_token = Integer()
     model = String()
 
-text_completion_request_queue = topic(
-    'text-completion', kind='non-persistent', namespace='request'
-)
-text_completion_response_queue = topic(
-    'text-completion-response', kind='non-persistent', namespace='response', 
-)
-
 ############################################################################
 
 # Embeddings
@@ -37,9 +30,22 @@ class EmbeddingsResponse(Record):
     error = Error()
     vectors = Array(Array(Double()))
 
-embeddings_request_queue = topic(
-    'embeddings', kind='non-persistent', namespace='request'
-)
-embeddings_response_queue = topic(
-    'embeddings-response', kind='non-persistent', namespace='response'
-)
+############################################################################
+
+# Tool request/response
+
+class ToolRequest(Record):
+    name = String()
+
+    # Parameters are JSON encoded
+    parameters = String()
+
+class ToolResponse(Record):
+    error = Error()
+
+    # Plain text aka "unstructured"
+    text = String()
+
+    # JSON-encoded object aka "structured"
+    object = String()
+
