@@ -18,8 +18,6 @@ class ObjectEmbeddings(Record):
     key_name = String()
     id = String()
 
-object_embeddings_store_queue = topic('object-embeddings-store')
-
 ############################################################################
 
 # Stores rows of information
@@ -29,5 +27,5 @@ class Rows(Record):
     row_schema = RowSchema()
     rows = Array(Map(String()))
 
-rows_store_queue = topic('rows-store')
+
 
